<?php
require("lib_gpio.php");
require("lib_i2cCmd.php");

define("GPIO_RUN_STATUS", 21);
define("GPIO_PWM", 1);
define("GPIO_UPPER_RED", 4);
define("GPIO_UPPER_BLUE", 17);

//setting file read
$ini = parse_ini_file('setting.ini');
$setting_pwm_duty = $ini['setting_pwm_duty'];
$luxThresh = $ini['setting_lux_threshold'];
$upperRedStatus = $ini['setting_upper_red'];
$upperBlueStatus = $ini['setting_upper_blue'];

// init
$systemRunStatus = gpio_read(GPIO_RUN_STATUS);
if($systemRunStatus == GPIO_HIGH){
    print("initializing process worked\n");
    gpio_pwm_init();
    gpio_mode(GPIO_UPPER_RED, GPIO_OUT);
    gpio_write(GPIO_UPPER_RED, $ini['setting_upper_red']);
    gpio_mode(GPIO_UPPER_BLUE, GPIO_OUT);
    gpio_write(GPIO_UPPER_BLUE, $ini['setting_upper_blue']);
    //set initializing process close
    gpio_write(GPIO_RUN_STATUS, GPIO_LOW);
}

//Upper Shelf Red
if(isset($_POST['upperShelfRed'])){
    if($_POST['upperShelfRed'] == 'UpperShelfRedOn'){
        $upperRedStatus = GPIO_HIGH;
    } else {
        $upperRedStatus = GPIO_LOW;
    }
    $ini['setting_upper_red'] = $upperRedStatus;
}
//Upper Shelf Blue
if(isset($_POST['upperShelfBlue'])){
    if($_POST['upperShelfBlue'] == 'UpperShelfBlueOn'){
        $upperBlueStatus = GPIO_HIGH;
    } else {
        $upperBlueStatus = GPIO_LOW;
    }
    $ini['setting_upper_blue'] = $upperBlueStatus;
}

//Lux setting
if(isset($_POST['luxThresh'])){
    $luxThresh = $_POST['luxThresh'];
    if(ctype_digit($luxThresh)){
        $ini['setting_lux_threshold'] = $luxThresh;
    }
}
$currentLux = luxByTsl2561();
if($currentLux > $luxThresh){
    $msg = sprintf("Bright Lux:%d", luxByTsl2561());
    echo $msg;
    gpio_write(GPIO_UPPER_RED, GPIO_LOW);
    gpio_write(GPIO_UPPER_BLUE, GPIO_LOW);
} else {
    $msg = sprintf("Dark Lux:%d", luxByTsl2561());
    echo $msg;
    gpio_write(GPIO_UPPER_RED, $ini['setting_upper_red']);
    gpio_write(GPIO_UPPER_BLUE, $ini['setting_upper_blue']);
}

//PWM
if(isset($_POST['duty'])){
    $duty = $_POST['duty'];
    if(ctype_digit($duty)){
        gpio_pwm_setDuty($duty);
        //$msg = sprintf("PWM duty ratio is set to %d", $duty);
        //echo $msg;
        $ini['setting_pwm_duty'] = $duty;
    }
}

//update initial file
$fp = fopen('setting.ini', 'w');
foreach($ini as $key => $value) fputs($fp, "$key=$value\n");
fclose($fp);

//water circulation
$file = fopen('scheduleWaterCirc.ini', 'rb');
flock($file, LOCK_SH);
$settings =array();
while($line = fgetcsv($file,1024,":")){
    $elements = array();
    $elements['HOUR'] = $line[0];
    $elements['MIN'] = $line[1];    
    $elements['RUN'] = $line[2];
    array_push($settings, $elements);
}
fclose($file);
if($_POST['action'] == 'remove'){
//if(isset($_POST['schedule'])){
    unset($settings[$_POST['scheduleRemove']]);
    $settings = array_values($settings);
    $file = fopen('scheduleWaterCirc.ini', 'wb');
    flock($file, LOCK_SH);
    foreach($settings as $elements){
        fwrite($file, implode(":", $elements)."\r\n");
    }
    fclose($file);
}

if($_POST['action'] == 'add'){
//    $newAdd = sprintf("At %02d:%02d %02dmin Run",$_POST['scheduleAddHour'],$_POST['scheduleAddMin'],$_POST['scheduleAddRun']);
//    print $newAdd;
    $i=0;
    $j=0;
    $elements = array();
    $elements['HOUR'] = $_POST['scheduleAddHour'];
    $elements['MIN'] = $_POST['scheduleAddMin'];    
    $elements['RUN'] = $_POST['scheduleAddRun'];
    array_push($settings, $elements);

//sort
    $sortVal = array();
    for($i=0;$i<count($settings);$i++){
        array_push($sortVal, ($settings[$i]['HOUR']*100 + $settings[$i]['MIN']));
    }
    for($i=1; $i<count($sortVal);$i++){
        $tmp = $sortVal[$i];
        for($j=$i-1; $j>=0 && $sortVal[$j] > $tmp; $j--){
            $sortVal[$j+1] = $sortVal[$j];
        }
        $sortVal[$j+1] = $tmp;
    }
    //print_r($sortVal);

    //create new array
    $newSettings = array();
    for($i=0; $i < count($sortVal); $i++){
        for($j=0; $j < count($settings); $j++){
            if($sortVal[$i] == ($settings[$j]['HOUR']*100 + $settings[$j]['MIN'])){
                array_push($newSettings, $settings[$j]);
            }
        }
    }
//    print_r($newSettings);
    $settings = $newSettings;
    $file = fopen('scheduleWaterCirc.ini', 'wb');
    flock($file, LOCK_SH);
    foreach($settings as $elements){
        fwrite($file, implode(":", $elements)."\r\n");
    }
    fclose($file);
}

?>
<!DOCTYPE html>
<html
<head>
<meta charset="utf-8">
<title>Hydropnics</title>
</head>
<body>
<header>
	<div class="header">
	</div>
</header>

<div id="contents">
	<section>
		<div class="wmain">
		<form action="" method="POST">
        Upper Shelf Red
        <input type="radio" name="upperShelfRed" value="UpperShelfRedOff" <?php if($upperRedStatus == GPIO_LOW){echo 'checked';} ?>>Off
        <input type="radio" name="upperShelfRed" value="UpperShelfRedOn" <?php if($upperRedStatus == GPIO_HIGH){echo 'checked';} ?>>On
        <br>
        Upper Shelf Blue
        <input type="radio" name="upperShelfBlue" value="UpperShelfBlueOff" <?php if($upperBlueStatus == GPIO_LOW){echo 'checked';} ?>>Off
        <input type="radio" name="upperShelfBlue" value="UpperShelfBlueOn" <?php if($upperBlueStatus == GPIO_HIGH){echo 'checked';} ?>>On
        <br>
        PWM duty
        <input type="text" name="duty" value="<?=$ini['setting_pwm_duty'] ?>" size="15">
        <br>
        Lux threshold
        <input type="text" name="luxThresh" value="<?=$ini['setting_lux_threshold'] ?>" size="15">
        <br>
		<input type="submit" name="setDuty" value="update" />
		</form>
		</div>
	</section>

    <form action="" method="POST">
    <select name="scheduleRemove" size=<?php print "\"".count($settings)."\">"; ?>
<?php
    for($i=0;$i < count($settings);$i++){
        $oneList = sprintf('At %02d:%02d %02dmin Run', $settings[$i]['HOUR'], $settings[$i]['MIN'], $settings[$i]['RUN']);
        print '<option name="selectSchedule" value='.$i.'>';
        print $oneList;
        print '</option>';
    }
?>
    </select>
    <br>
    <input type="submit" name="action" value="remove" />
    </form>
    <form action="" method="POST">
    <select name="scheduleAddHour">
    <?php
    for($i=0;$i<24;$i++){
        if($i == 12){
            print '<option value=12 selected>';
        }
        else{
            print '<option value='.$i.'>';
        }
        print $i;
        print '</option>';
    }
?>
    </select>
    <select name="scheduleAddMin">
    <?php
    for($i=0;$i<60;$i++){
        if($i == 30){
            print '<option value=30 selected>';
        }
        else{
            print '<option value='.$i.'>';
        }
        print $i;
        print '</option>';
    }
    ?>
    </select>
    <select name="scheduleAddRun">
    <?php
    for($i=1;$i<=10;$i++){
        if($i == 5){
            print '<option value=5 selected>';
        }
        else{
            print '<option value='.$i.'>';
        }
        print $i;
        print '</option>';
    }
    ?>
    </select>
    <br>
    <input type="submit" name="action" value="add" />
    </form>
    
</div>

</body>
</html>
